@@ -9,10 +9,11 @@ import VectorBuilder.Prelude hiding (many, some)
 import Data.Vector (Vector)
 import qualified VectorBuilder.Builder as A
 import qualified VectorBuilder.Vector as B
+import qualified Data.Vector.Generic as C
 
 
 {-# INLINABLE many #-}
-many :: Alternative m => m a -> m (Vector a)
+many :: (Alternative m, C.Vector vector a) => m a -> m (vector a)
 many = fmap B.build . manyBuilder
 
 {-# INLINABLE manyBuilder #-}
@@ -22,7 +23,7 @@ manyBuilder m = let
   in loop
 
 {-# INLINABLE some #-}
-some :: Alternative m => m a -> m (Vector a)
+some :: (Alternative m, C.Vector vector a) => m a -> m (vector a)
 some m = B.build <$> someBuilder m
 
 {-# INLINABLE someBuilder #-}
